@@ -49,7 +49,8 @@ class Node:
         :rtype: null
         """
         if os.name == 'nt':
-            command = "geth --identity {0} --http --http.port {1} --http.corsdomain \"*\" --datadir \"{2}\" --port " \
+            command = "geth --identity {0} --syncmode \"light\" --http --http.port {1} --http.corsdomain \"*\" " \
+                      "--datadir \"{2}\" --port " \
                       "{3} --nodiscover --http.api  \"eth,net,web3,personal,miner,admin\" --networkid {4} --nat " \
                       "\"any\" --ipcdisable --allow-insecure-unlock ".format(str(self.name), str(self.rpcport),
                                                                              str(self.datadir),
